"use strict";
/*
 * Copyright (c) 2020, salesforce.com, inc.
 * All rights reserved.
 * Licensed under the BSD 3-Clause license.
 * For full license text, see LICENSE.txt file in the repo root or https://opensource.org/licenses/BSD-3-Clause
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.searchUp = exports.createFiles = exports.ensureFileExists = exports.ensureDirectoryExists = void 0;
const fs = require("graceful-fs");
const path = require("path");
function ensureDirectoryExists(filePath) {
    if (fs.existsSync(filePath)) {
        return;
    }
    ensureDirectoryExists(path.dirname(filePath));
    fs.mkdirSync(filePath);
}
exports.ensureDirectoryExists = ensureDirectoryExists;
function ensureFileExists(filePath) {
    ensureDirectoryExists(path.dirname(filePath));
    fs.closeSync(fs.openSync(filePath, 'w'));
}
exports.ensureFileExists = ensureFileExists;
/**
 * Method to save multiple files on disk.
 *
 * @param fileMap key = filePath, value = file contents
 */
function createFiles(fileMap) {
    for (const filePath of fileMap.keys()) {
        ensureFileExists(filePath);
        const writeStream = fs.createWriteStream(filePath);
        writeStream.write(fileMap.get(filePath));
        writeStream.end();
    }
}
exports.createFiles = createFiles;
/**
 * Traverse up a file path and search for the given file name.
 *
 * @param start File or folder path to start searching from
 * @param fileName File name to search for
 */
function searchUp(start, fileName) {
    const filePath = path.join(start, fileName);
    if (fs.existsSync(filePath)) {
        return filePath;
    }
    const parent = path.resolve(start, '..');
    if (parent === start) {
        return;
    }
    return searchUp(parent, fileName);
}
exports.searchUp = searchUp;
//# sourceMappingURL=fileSystemHandler.js.map