import { SourcePath } from '../common';
import { MetadataXml } from '../resolve';
import { Optional } from '@salesforce/ts-types';
/**
 * Get the file or directory name at the end of a path. Different from `path.basename`
 * in that it strips anything after the first '.' in the name.
 * @param fsPath The path to evaluate
 */
export declare function baseName(fsPath: SourcePath): string;
/**
 * Get the name of file path extension. Different from path.extname in that it
 * does not include the '.' in the extension name. Returns an empty string if
 * there is no extension.
 * @param fsPath The path to evaluate
 */
export declare function extName(fsPath: SourcePath): string;
/**
 * Get the name of the parent to the last portion of a path
 * @param fsPath The path to evaluate
 */
export declare function parentName(fsPath: SourcePath): string;
/**
 * Trim a path up until and including the given part. Returns `fsPath`
 * if the path `part` was not found.
 * @param fsPath Path to trim
 * @param part Path part to trim up until
 */
export declare function trimUntil(fsPath: SourcePath, part: string): string;
/**
 * Returns the `MetadataXml` info from a given file path. If the path is not a
 * metadata xml file (-meta.xml), returns `undefined`.
 *
 * @param fsPath - File path to parse
 * @returns MetadataXml info or undefined
 */
export declare function parseMetadataXml(fsPath: string): Optional<MetadataXml>;
/**
 * Returns the fullName for a nested metadata source file. This is for metadata
 * types that can be nested more than 1 level such as report and reportFolder,
 * dashboard and dashboardFolder, etc. It uses the directory name for the metadata type
 * as the starting point (non-inclusively) to parse the fullName.
 *
 * Examples:
 * (source format path)
 * fsPath: force-app/main/default/reports/foo/bar/My_Report.report-meta.xml
 * returns: foo/bar/My_Report
 *
 * (mdapi format path)
 * fsPath: unpackaged/reports/foo/bar-meta.xml
 * returns: foo/bar
 *
 * @param fsPath - File path to parse
 * @param directoryName - name of directory to use as a parsing index
 * @returns the FullName
 */
export declare function parseNestedFullName(fsPath: string, directoryName: string): Optional<string>;
